@@ -118,6 +118,11 @@ class Wavelet:
         self.original_ts = series
         self.freq = freq
         self.kwargs = kwargs
+
+        # Installing WaveletComp if requiered
+        commands = """if("WaveletComp" %in% rownames(installed.packages()) == FALSE) 
+                   {install.packages("WaveletComp")}"""
+        r(commands)
         
         # CALCULAR CWT
         if len(series) == 1:
